==> haskell-insert-ordered-containers-0.2.1.0-138-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: insert-ordered-containers
version: 0.2.1.0
id: insert-ordered-containers-0.2.1.0-AvSLGeYSHV7D0buivlnUWo
key: insert-ordered-containers-0.2.1.0-AvSLGeYSHV7D0buivlnUWo
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/insert-ordered-containers#readme
synopsis: Associative containers retating insertion order for traversals.
description:
    Associative containers retating insertion order for traversals.
category: Web
abi: d061aa23bcc2f981bd9b86000cd017d4
exposed: True
exposed-modules:
    Data.HashMap.Strict.InsOrd
import-dirs: /usr/lib/ghc-8.6.4/site-local/insert-ordered-containers-0.2.1.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/insert-ordered-containers-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/insert-ordered-containers-0.2.1.0
hs-libraries: HSinsert-ordered-containers-0.2.1.0-AvSLGeYSHV7D0buivlnUWo
depends:
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    lens-4.17-Ho2XjZ15d8i5p2rFPy4ulk
    semigroupoids-5.3.2-4vMxTU7QUhTAhqMRKNGi6Q text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock
haddock-html: /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-insert-ordered-containers-0.2.1.0-139-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: insert-ordered-containers
version: 0.2.1.0
id: insert-ordered-containers-0.2.1.0-KqaX1tWMwu2DsFU1KGV5kc
key: insert-ordered-containers-0.2.1.0-KqaX1tWMwu2DsFU1KGV5kc
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/insert-ordered-containers#readme
synopsis: Associative containers retating insertion order for traversals.
description:
    Associative containers retating insertion order for traversals.
category: Web
abi: bbdb1bec7a8751e9a06e8899a3d2f103
exposed: True
exposed-modules:
    Data.HashMap.Strict.InsOrd
import-dirs: /usr/lib/ghc-8.6.4/site-local/insert-ordered-containers-0.2.1.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/insert-ordered-containers-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/insert-ordered-containers-0.2.1.0
hs-libraries: HSinsert-ordered-containers-0.2.1.0-KqaX1tWMwu2DsFU1KGV5kc
depends:
    aeson-1.4.2.0-QHLwhPMHVB663aXnGqoMq base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    lens-4.17-F6A8Oj3hNsE3ZcSNZZdK9Q
    semigroupoids-5.3.2-lJuIn7iVWXJJzZoPYyt6n text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock
haddock-html: /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
